usb: musb: clear RXCSR_AUTOCLEAR before PIO read

If RXCSR_AUTOCLEAR flag is not cleard before PIO reading, one packet
may be recieved by musb fifo, but no chance to notify
software, so cause packet loss, follows the detailed process:

	- PIO read one packet
	- musb fifo auto clear the MUSB_RXCSR_RXPKTRDY
	- musb continue to recieve the next packet, and MUSB_RXCSR_RXPKTRDY
	is set
	- software clear the MUSB_RXCSR_RXPKTRDY, so there is no chance for
	musb to notify software that the 2nd recieved packet.

The patch does fix the g_ether issue below:

	- use fifo_mode 3 to enable double buffer
	- 'ping -s 1024 IP_OF_BEAGLE_XM'
	- one usb packet of 512 byte is lost, so ping failed,
	which can be observed by wireshark

note:
	Beagle xm takes musb rtl1.8 and may fallback to pio mode
	for unaligned buffer.

Signed-off-by: Ming Lei <tom.leiming@gmail.com>
Signed-off-by: Felipe Balbi <balbi@ti.com>
diff --git a/drivers/usb/musb/musb_gadget.c b/drivers/usb/musb/musb_gadget.c
index 0169dcf..363cfad 100644
--- a/drivers/usb/musb/musb_gadget.c
+++ b/drivers/usb/musb/musb_gadget.c
@@ -765,10 +765,11 @@
 			 if (is_dma_capable() && musb_ep->dma) {
 				unmap_dma_buffer(req, musb);
 
 				/* Clear DMAENAB for the
 				 * PIO mode transfer
 				 */
-				csr &= ~MUSB_RXCSR_DMAENAB;
+				csr &= ~(MUSB_RXCSR_DMAENAB | MUSB_RXCSR_AUTOCLEAR);
 				musb_writew(epio, MUSB_RXCSR, csr);
 			}
@@ -765,10 +765,11 @@
 				unmap_dma_buffer(req, musb);
 
-				/* Clear DMAENAB for the
+				/*
+				 * Clear DMAENAB and AUTOCLEAR for the
 				 * PIO mode transfer
 				 */